Chiplotle-HPGL commands — Chiplotle v0.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.2 documentation »
- Chiplotle API »

# Chiplotle-HPGL commands

class `chiplotle.hpgl.commands.` `AA`(xy, angle, chordtolerance=None)

  Bases: `chiplotle.hpgl.abstract.arc._Arc`

  Arch absolute: | Draws an arc, using absolute coordinates, that starts at the current pen location and uses the specified center point.

  - xy : `(x, y)` position pair.
  - angle : `float` [-360 to 360]. The arch angle in degrees.
  - chordtolerance : `float` [0.36 to 180], `None`.

class `chiplotle.hpgl.commands.` `AF`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Advance full page:
  | Advances roll paper one full page length and establishes the origin at the center of the new page.

class `chiplotle.hpgl.commands.` `AH`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Advance half page:
  | Advances roll paper one half page length and establishes the origin at the center of the new page.

class `chiplotle.hpgl.commands.` `AP`(n=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Automatic pen operations:
  | Controls automatic pen operations sich as returning a pen to the carousel if it has been in the holder without drawing for a certain time.

  For 7550:

  bit_no | dec_val | state | meaning
  --- | --- | --- | ---
  0 | 1 | 1 | lift pen if down too long without motion
  0 | 0 | 0 | do not lift pen until PU received
  1 | 2 | 1 | put pen away if too long without motion
  1 | 0 | 0 | do not put pen away until SP0 received
  2 | 4 | 1 | do not get new pen until drawing starts
  2 | 0 | 0 | get pen immediately after SP command
  3 | 8 | 1 | merge all pen up moves
  3 | 0 | 0 | do not merge all pen up moves

  default is 7 on 7550 codes are 0 to 255 with default of 95 on the DraftMaster

  `format`

class `chiplotle.hpgl.commands.` `AR`(xy, angle, chordtolerance=None)

  Bases: `chiplotle.hpgl.abstract.arc._Arc`

  Arch relative: | Draws an arc, using relative coordinates, that starts at the current pen location and uses the specified center point.

  - xy : `(x, y)` position pair.
  - angle : `float` [-360 to 360]. The arch angle in degrees.
  - chordtolerance : `float` [0.36 to 180], `None`.

class `chiplotle.hpgl.commands.` `AS`(accel=None, pen=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Acceleration select:
  | Sets pen acceleration for one or all pens. The default acceleration is suitable for all recommended pen and media combinations. Slowing the acceleration may improve line quality if you are using heavier than recommended media.

  - accel : `int` [1 to 4] , `None`.
  - pen : `int` [1 to 8], `None`. When `None`, accel is applied to all pens.
  `format`

class `chiplotle.hpgl.commands.` `B`

  Bases: `chiplotle.hpgl.abstract.hpglescape._HPGLEscape`

  Escape output buffer space:

class `chiplotle.hpgl.commands.` `BF`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Buffer plot.

class `chiplotle.hpgl.commands.` `BL`(label=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Buffer label: | Stores a label in the label buffer. You can then use the output length (`OL`) instruction to determine its space requirement prior to drawing it. Or, you can use the plot buffer (`PB`) instruction to repeatedly plot this label.

  `format`

class `chiplotle.hpgl.commands.` `CA`(set=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Designate alternate character set:
  | Designates a character set as the alternate character set to be used in labeling instructions. Use this instruction to provide an additional character set that you can easily access in a program.

  - set : `int` [-1, 0 to 59, 60, 70, 80, 99, 100, 101], default 0.
  `format`

class `chiplotle.hpgl.commands.` `CC`(angle=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Character chord angle:
  | Sets the chord angle that determines the smoothness of characters drawn when you select one of the arc-font character sets for labeling.

  `format`

class `chiplotle.hpgl.commands.` `CI`(radius, chordangle=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Circle: | Draws a circle using the specified radius and chord tolerance. If you want a filled circle, refer to the `WG` or `PM` instruction.

  `format`
  `radius`
    The radius of the circle.

class `chiplotle.hpgl.commands.` `CM`(switch=None, fallback=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Character selection mode:
  | Specifies mode of character set selection and usage. Use this instruction to select the alternate HP 8-bit, ISO 7-bit, or ISO 8-bit character modes.

  - switch : `int` [0 to 3], default 0.
  - fallback : `int` 0 or 1, default 0.
  `format`

class `chiplotle.hpgl.commands.` `CP`(spaces=None, lines=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Character plot: | Move the pen the specified number of character plot cells from the current pen location.

  `format`

class `chiplotle.hpgl.commands.` `CS`(set=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Standard character set:
  | Designates a character set as the standard character set for labeling instruction. Use this instruction to change the default ANSI ASCII english set to one with characters appropriate to your application. This instruction is particularly useful if you plot most of your labels in a language other than english.

  `format`

class `chiplotle.hpgl.commands.` `CT`(type=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Chord tolerance:
  | Determines whether the chord tolerance parameter of the `CI`, `AA`, `AR` and `WG` instructions is interpreted as a chord angle in degrees or as a deviation distance in current units.

  - type : `int` 0 or 1, default 0.
  `format`

class `chiplotle.hpgl.commands.` `CV`(n=None, inputdelay=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Curved line generator:
  | Collects vectors (line segments) in the vector buffer so that they can be plotted as a group. This allows the plotter to plot in a continuous motion, rather than stopping and starting at each vector endpoint. As a result, curves appear smoother.

  - n : `int` 0 or 1, default 1 (on).
  - inputdelay : `int` [0 to 8,388,607] msec, default 100.
  `format`

class `chiplotle.hpgl.commands.` `DC`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Digitizer clear:
  | Terminates digitize mode. For example, if you are using an interrupt routine in a digitizing program to branch to another plotting function, use DC to clear the digitize mode immediately after branching.

class `chiplotle.hpgl.commands.` `DF`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Default: | Sets certain plotter functions to predefined default conditions. Use this instruction to return the plotter to a known state while maintaining the current location of P1 and P2. When you use DF at the beginning of a program, unwanted graphics parameters such as character size, slant, or scaling are not inherited from another program.

class `chiplotle.hpgl.commands.` `DI`(run=None, rise=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Absolute direction:
  | Specifies the direction in which labels are drawn, independent of P1 and P2 settings. Use this instruction to change labeling direction when you are labeling line charts, schematic drawings, blueprints, and survey boudaries.

  - run : `float`. cos(angle)
  - rise : `float`. sin(angle)
  `format`

class `chiplotle.hpgl.commands.` `DP`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Digitize point: | Returns the X,Y coordinates of a selected point on a plot to the computer for later use. Use this instruction to input data for a graphics program or to obtain the coordinates of a point or points on plot.

class `chiplotle.hpgl.commands.` `DR`(run=None, rise=None)

  Bases: `chiplotle.hpgl.commands.DI`

  Relative direction:
  | Specifies the direction in which labels are drawn relative to the scaling points P1 and P2. Label direction is adjusted when P1 and P2 change so that labels maintain the same relationship to the plotted data. Use `DI` if you want label direction to be independent or P1 and P2.

  - run : `float`. cos(angle)
  - rise : `float`. sin(angle)

class `chiplotle.hpgl.commands.` `DS`(slot=None, set=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Designate character set into slot:
  | Designates up to four character sets to be immediately available for plotting. Used with ISO character sets and modes.

  `format`

class `chiplotle.hpgl.commands.` `DT`(terminator='x03')

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Define label terminator:
  | Specifies the ASCII character to be used as the label terminator. Use this instruction to define a new label terminator if your computer cannot use the default terminator (ETX, decimal code 3).

  `format`

class `chiplotle.hpgl.commands.` `DV`(vertical=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Direction vertical:
  | Specifies vertical mode as the direction for subsequent labels. Use this instruction to ‘stack’ horizontal characters in a column. A carriage return and a line feed lace the next ‘column’ to the left of the previous one.

  `format`

class `chiplotle.hpgl.commands.` `EA`(xy)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Edge rectangle absolute:
  | Defines and outlines a rectangle using absolute coordinates.

  - xy : `(x, y)`. The absolute coordinates of the remaining corner.

class `chiplotle.hpgl.commands.` `EC`(n=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Enable cut line:
  | Draws a dashed cut line between ‘pages’ on roll paper to indicate where to cut the paper. Used with `AF`, `AH` and `PG` instructions.

  `format`

class `chiplotle.hpgl.commands.` `EP`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Edge polygon: | Outlines the polygon currently stored in the polygon buffer. Use this instruction to edge polygons that you defined in polygon mode (`PM`) and with the rectangle and wedge instructions (`RA`, `RR` and `WG`).

class `chiplotle.hpgl.commands.` `ER`(xy)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Edge rectangle relative:
  | Defines and outlines a rectangle using relative coordinates.

  - xy : `(x, y)`. The relative coordinates of the remaining corner.

class `chiplotle.hpgl.commands.` `ES`(charspace=None, linespace=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Extra space: | Adjust space between characters and lines of labels without affecting character size.

  - charspace : `float`, `None`. Spacing between characters.
  - linespace : `float`, `None`. Spacing between lines.
  `format`

class `chiplotle.hpgl.commands.` `EW`(radius, startangle, sweepangle, chordangle=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Edge wedge: | Outlines any wedge. Use these instructions to produce sectors of a pie chart.

  - radius : `float`.
  - startangle : `float` [0 - 360] degrees.
  - sweepangle : `float` [0 - 360] degrees.
  - chordangle : `float` [0.36 - 50] degrees.
  `format`

class `chiplotle.hpgl.commands.` `ExtendedError`

  Bases: `chiplotle.hpgl.abstract.hpglescape._HPGLEscape`

  Extendederror: | Get RS-232-C related error message.

  error num | meaning
  --- | ---
  0 | no i/o error
  10 | output request received while still processing previous one
  11 | invalid byte received after escape sequence (“ESC.”)
  12 | invalid byte received as part of a device control instruction
  13 | parameter out of range
  14 | too many parameters received
  15 | framing, parity, or overrun error
  16 | input buffer overflow

class `chiplotle.hpgl.commands.` `FP`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Fill polygon: | Fills the polygon currently in the polygon buffer. Use FP to fill polygons defined in polygon mode ( `PM`) and defined with the edge rectangle and wedge instructions ( `EA`, `ER`, and `EW`).

class `chiplotle.hpgl.commands.` `FR`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Advance frame: | Advances paper to the next plot frame and calculates a relative coordinate system for that frame. Use FR to do multi-frame long-axis plotting.

class `chiplotle.hpgl.commands.` `FS`(force=None, pen=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Force select: | Sets pen pressure to the paper for one or all pens. Use this instruction to optimize pen life and line quality for each pen and paper combination.

  - force : `int` [1 to 8]
  - pen : `int` [1 to 8]. If pen is `None` then all pens are set.
  `format`

class `chiplotle.hpgl.commands.` `FT`(type=None, space=None, angle=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Fill type: | Selects the shading pattern used in polygons (`FP`), rectangles (`RA` or `RR`), or wedges (`WG`). Use this instruction to enhance plots with solid fill, parallel lines (hatching), cross-hatching, or a fill pattern you designed using the user-defined fill type (UF) instruction.

  - type : `int` 1 or 2, Solid (space and angle ignored) 3: Hatching, 4: Cross hatching.
  `format`

class `chiplotle.hpgl.commands.` `GC`(count=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Group count: | Allows you to assign an arbitrary number that will be output by the `OG` instruction. Use `GC` with the `OG` instruction to monitor the successful transfer of data blocks in spooling applications.

  `format`

class `chiplotle.hpgl.commands.` `IN`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Initialize: | Resets most plotter functions to their default settings. Use this instruction to return the plotter to a known state and to cancel settings that may have been changed by a previous program.

class `chiplotle.hpgl.commands.` `IP`(coords=None)

  Bases: `chiplotle.hpgl.abstract.twopoint._TwoPoint`

  Input p1 and p2:
  | Allows you to establish new or default locations for the scaling points P1 and P2. P1 and P2 are used by the scale instruction (`SC`) to establish user-unit scaling. The `IP` instruction is often used to ensure that a plot is always the same size, regardless of how P1 and P2 might have been set from the front panel or the size of media loaded in the plotter.

class `chiplotle.hpgl.commands.` `IV`(slot=None, left=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Invoke character slot:
  | Invokes a character set slot into either the right or left half of the in-use code table. Primarily used with ISO modes of character selection.

  `format`

class `chiplotle.hpgl.commands.` `IW`(coords=None)

  Bases: `chiplotle.hpgl.abstract.twopoint._TwoPoint`

  Input window: | Defmines a rectangular area, or window, that establishes soft-clip limits. Subsequent programmed pen motion will be restricted to this area. Use this instruction when you want to be sure that your plot falls within a specified area.

class `chiplotle.hpgl.commands.` `K`

  Bases: `chiplotle.hpgl.abstract.hpglescape._HPGLEscape`

  Abort command: | Tells the plotter to discard commands in its buffer.

class `chiplotle.hpgl.commands.` `KY`(key=None, function=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Define key: | Assigns a predefined function to one of the frontal panel function keys. Use this instruction with the WD instruction when designing interactive programs.

  `format`

class `chiplotle.hpgl.commands.` `LB`(text)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Label: | Plots text using the currently defined character set.

  `format`

class `chiplotle.hpgl.commands.` `LO`(origin=1)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Label origin: | Positions labels relative to current pen location. Use LO to center, left justify, or right justify label. The label can be drawn above or below the current pen location and can also be offset by an amount equal to 1/2 the character’s width and height.

  - origin : `int` [1-9] or [11-19].
  `format`

class `chiplotle.hpgl.commands.` `LT`(pattern=None, length=4)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Line type: | Specifies the line pattern to be used when drawing linese and nonsolid fill types. Use LT to emphasize or de-emphasize other plotter lines and shapes.

  - pattern : `int` [-6 to 6]
  - length : `float` [0 to 100]

  0 | plot point at given point.
  1 | . . . . . .
  2 |
  3 | ___ ___ ___ ___ ___
  4 | __.__.__.__.__.__.
  5 | ___ _ ___ _ ___ _ ___ _
  6 | ___ _ _ ___ _ _ ___ _ _ ___

  `format`

class `chiplotle.hpgl.commands.` `NR`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Not ready: | Programmatically simulates pressing VIEW. However, you cannot take the plotter out of the view state with NR instruction.

class `chiplotle.hpgl.commands.` `OA`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output actual pen status:
  | Outputs the current pen location (in plotter units) and up/down position. Use this information to position a label or figure, to determine the parameters of a window, or to determine the pen’s curent location if you moved it using front-panel cursor buttons.

class `chiplotle.hpgl.commands.` `OC`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output commanded pen status:
  | Ouput the location and up/down position of the last commanded pen move instruction. Use OC to position a label or determine the parameters of an instruction that tried to move the pen beyond the limits of some window. You can also use this instruction when you want to know the pen’s location in user units.

class `chiplotle.hpgl.commands.` `OD`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output digitized point and pen status:
  | Outputs the X,Y coordinates and up/down pen position associated with the last digitized point. Use this instruction after the `DP` instruction to return the coordinates of the digitized point to your computer.

class `chiplotle.hpgl.commands.` `OE`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output error: | Output a number corresponding to the type of HP-GL error (if any) received by the plotter after the most recent `IN` or `OE` instruction. Use this instruction for debugging programs.

  bit value | error no | meaning
  --- | --- | ---
  0 | 0 | no error
  1 | 1 | unrecognized command
  2 | 2 | wrong num of parameters
  4 | 3 | out-of-range parameter
  8 | 4 | unused
  16 | 5 | unknown character set
  32 | 6 | position overflow
  64 | 7 | unused
  128 | 8 | pinch wheels raised

  Note

  some error meanings change depending on the plotter!

class `chiplotle.hpgl.commands.` `OF`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output factors: | Outputs the number of plotter units per millimeter in each axis. This lets you use the plotter with sofware that needs to know the size of a plotter unit.

class `chiplotle.hpgl.commands.` `OG`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output group count:
  | Outputs the data block number of the current group count and whether the escape function has been activated. Use this instruction at the end of a data block in spooling applications, where it is important to know the current data block number and whether the data block has been transferred.

class `chiplotle.hpgl.commands.` `OH`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output hard-clip limits:
  | Outputs the X,Y coordinates of the current hard-clip limits. Use this instruction to determine the plotter unit dimension of the area in which plotting can occur.

class `chiplotle.hpgl.commands.` `OI`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output identification:
  | Outputs the plotter’s identifying model number. This information is useful in a remote operating configuration to determine which plotter model is on-line, or when software needs the plotter’s model number.

class `chiplotle.hpgl.commands.` `OK`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output key: | Outputs a number that indicates which, if any, of the front-panel function keys has been pressed. use this instruction with the `WD` instruction when designing interactive programs.

class `chiplotle.hpgl.commands.` `OL`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output label length:
  | Outputs information about the label contained in the label buffer.

class `chiplotle.hpgl.commands.` `OO`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output options: | Outputs eight option parameters indicating the features implemented on the plotter. Some software packages use this feature to determine which plotter capabilities exist.

class `chiplotle.hpgl.commands.` `OP`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output p1 and p2:
  | Outputs the X,Y coordinates (in plotter units) of the current scaling points P1 and P2. Use this instruction to determine the numberic coordinates or P1 and P2 when they have been set manually, and to help compute the number of plotter units per user units when scaling is on. This instruction can also be used with the input window (`IW`) instruction to programmatically set the window to P1 and P2.

class `chiplotle.hpgl.commands.` `OS`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output status: | Outputs the decimal value of the status byte. Use this instruction in debugging operations and in digitizing applications.

  bit value | bit position | meaning
  --- | --- | ---
  1 | 0 | pen down
  2 | 1 | P1 or P2 changed (“OP” clears)
  4 | 2 | digitized point ready (“OD” clears)
  8 | 3 | initialized (“OS” clears)
  16 | 4 | ready to recieve data (always 0)
  32 | 5 | There is an error (“OE” clears)
  64 | 6 | unused
  128 | 7 | unused

  power-on status == 24 (bits 3 & 4 set)

class `chiplotle.hpgl.commands.` `OT`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output carousel type:
  | Outputs information on the type of carousel loaded and the stalls occupied.

class `chiplotle.hpgl.commands.` `OW`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Output window: | Outputs the X,Y coordinates of the lower-left and upper-right corners of the window area in which plotting can occur. This instruction is especially useful when the window area (defined by `IW`) extends beyond the hard-clip limits.

class `chiplotle.hpgl.commands.` `Off`

  Bases: `chiplotle.hpgl.abstract.hpglescape._HPGLEscape`

  Off: | Places the plotter in a programmed off-state.

class `chiplotle.hpgl.commands.` `On`

  Bases: `chiplotle.hpgl.abstract.hpglescape._HPGLEscape`

  On: | Places the plotter in a programmed on-state. Instructs the plotter to interpret data as HPGL and DCI instructions, rather than plotting the data stream as literal text characters.

class `chiplotle.hpgl.commands.` `PA`(xy=None)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Plot absolute: | Establishes absolute plotting and moves the pen to specified absolute coordinates using the current pen position.

class `chiplotle.hpgl.commands.` `PB`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Print buffer label:
  | Prints the contents of the label buffer.

class `chiplotle.hpgl.commands.` `PD`(xy=None)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Pen down: | Lowers the pen onto the writing surface for drawing and moves it to the coordinates/increments you specified.

  - xy : A `list` or `tuple` of x, y positions of the form `(x1, y2, x2, y2, x3, y3, ..., xn, yn)`.

class `chiplotle.hpgl.commands.` `PG`(n=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Page feed: | Advances roll paper one page length and establishes the plotter-unit origin at the center of the new page.

  `format`

class `chiplotle.hpgl.commands.` `PM`(n=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Polygon mode: | Enter polygon mode for defining shapes such as block letters, logos, surface charts, or any unique or intricate area for subsequent filling and/or edging. Fill polygons using the fill polygon (FP) instruction and/or outline them using the edge polygon (EP) instruction.

  `format`

class `chiplotle.hpgl.commands.` `PR`(xy=None)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Plot relative: | Establishes relative plotting and moves the pen (using the current position) to the specified points, each successive move relative to the last current pen location.

class `chiplotle.hpgl.commands.` `PS`(length=None, width=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Page size: | Changes the size of the hard clip limits.

  `format`

class `chiplotle.hpgl.commands.` `PT`(thickness=0.29999999999999999)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Pen thickness: | Determines the spacing between the parallel lines in solid fill patterns, according to the pen tip thickness.

  - thickness : `float` [0.1 to 5] mm, default is 0.3mm.
  `format`

class `chiplotle.hpgl.commands.` `PU`(xy=None)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Pen up: | Raises the pen from the plotting surface. Use this instruction to prevent stray lines from being drawn.

  - xy : A `list` or `tuple` of x, y positions of the form `(x1, y2, x2, y2, x3, y3, ..., xn, yn)`.

class `chiplotle.hpgl.commands.` `RA`(xy)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Filled rectangle absolute:
  | Defines and fills a rectangle using absolute coordinates.

  - xy : `(x, y)` tuple. The absolute coordinates of the remaining corner.

class `chiplotle.hpgl.commands.` `RO`(angle=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Rotate coordinate system:

  `format`

class `chiplotle.hpgl.commands.` `RP`(n=1)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Replot: |

  `format`

class `chiplotle.hpgl.commands.` `RR`(xy)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  Filled rectangle relative:
  | Defines and fills a rectangle using relative coordinates.

  - xy : `(x, y)` tuple. The relative coordinates of the remaining corner.

class `chiplotle.hpgl.commands.` `SA`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Select alternate character set:

class `chiplotle.hpgl.commands.` `SC`(coords=None)

  Bases: `chiplotle.hpgl.abstract.twopoint._TwoPoint`

  Scale: |

  Note

  DraftMaster also has a more complex version of ‘SC’ that is not implemented yet.

class `chiplotle.hpgl.commands.` `SI`(width=None, height=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Absolute character size:
  | Specifies the size of labeling characters in centimeters. Use this instruction to establish character sizing that is not dependent on the settings of P1 and P2.

  - width : `float` [-110 to 110] cm, excluding 0.
  - height : `float` [-110 to 110] cm, excluding 0.
  `format`

class `chiplotle.hpgl.commands.` `SL`(tan=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Character slant:
  | Argument is tan of desired angle.

  `format`

class `chiplotle.hpgl.commands.` `SM`(char=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Symbol mode: | Plots the char at each plotted point. char can be any printing ascii char, except ‘;’ Calling without an argument cancels symbol mode.

  `format`

class `chiplotle.hpgl.commands.` `SP`(pen=0)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Select pen: |

  `format`

class `chiplotle.hpgl.commands.` `SR`(width=None, height=None)

  Bases: `chiplotle.hpgl.commands.SI`

  Relative character size:
  | Specifies the relative size of characters as a percentage of the distance between P1 and P2. Use this instruction to establish relative character sizes so that if the P1/P2 distance changes, the character sizes adjust to occupy the same relative ammount of space.

  - width : `float` [-100 to 100] percent, excluding 0.
  - height : `float` [-100 to 100] percent, excluding 0.

class `chiplotle.hpgl.commands.` `SS`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Select standard character set:

class `chiplotle.hpgl.commands.` `TL`(tp=0.5, tn=0.5)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Length of ticks drawn with the XT and YT instructions.

  - tp : percentage of (P2y - P1y) for XT or (P2x - P1x) for YT. Denotes portion above X-axis or to the right of the Y-axis when

      difference is positive.

  - tn : same as tp except denotes portion below the X-axis and to the left of the Y-axis. 0.5 is default for both.

  `format`

class `chiplotle.hpgl.commands.` `VS`(vel=None, pen=None)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Pen velocity: | Set’s pen velocity.

  - vel : `float` [0.0 to 127.9999] (depends on plotter), `None`.
  - pen : `int` [1 to 8].
  `format`

class `chiplotle.hpgl.commands.` `WD`(text)

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Write to display:

  `format`

class `chiplotle.hpgl.commands.` `WG`(radius, startangle, sweepangle, chordangle=None)

  Bases: `chiplotle.hpgl.commands.EW`

  Filled wedge: |

class `chiplotle.hpgl.commands.` `XT`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  X tick: |

class `chiplotle.hpgl.commands.` `YT`

  Bases: `chiplotle.hpgl.abstract.hpglcommand._HPGLCommand`

  Y tick: |

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.2 documentation »
- Chiplotle API »